def knowledge_base() -> str:
    """
    Get the knowledge base for the ecommerce domain.
    
    Returns:
        str: The knowledge base for the ecommerce domain. The knowledge base is a markdown file, this
        functions returns it as a dumb string.
    """
    # Look for the domain_knowledge.md file in the knowledge_base directory
    # Return the file as a string
    with open("karta_benchmarks/evaluation_datasets/ecommerce/knowledge_base/domain_knowledge.md", "r") as file:
        return file.read()



TASK = {
    "task_name": "failed_payment_enquiry",
    "task_classification": "L1",
    "task_parameters": {
        "tool_use_multiplicity": 2,
        "customer_proficiency": 2,
        "sub_task_count": 2,
        "cost_of_failure": 1,
        "conversation_length_potential": 1,
        "domain_knowledge_richness": 1,
        "scope_for_alternate_closure": 1,
    },
    "task_complexity_score": 10,
    "customer_prompt": """Today is the 25th of May 2024. 

            You are Riddhima (riddhi@example.com). You have placed two orders yesterday. 
            One of the orders has an expensive Lenovo laptop. You paid for the order using your credit card, but the order has not
            been confirmed as yet. You know this because you usually receive a confirmation mail. The amount has been debited from your account.
            You are now very concerned and want to know what is happening.

            Start by sounding concerned and ask the agent to check the status of your order. Since you have multiple orders open, the agent will have to show you your
            order details and you will have to choose. Wait for him to do this. After picking the order which has the laptop, the agent will proceed to help you.

            If the agent is not able to resolve the issue immediately and asks you to wait till the payment is reversed, you should get frustrated and tell it that 
            this is the fourth time this has happened and you want to talk to a human. Donot stop conversing till you are transferred to a human. Remember you are 
            a benefits and rewards member and you should not have such a poor experience.

            If the payment is immediately reversed, you should be happy and say thank you.
            """,
    "judgement_criteria": """The agent must first retrieve the customer details using the customer email.
                    Then, it must retrieve the active orders for the customer.
                    Then, since there are multiple orders for the customer, the must summarize the order details and present them to the customer.
                    After the customer identifies the order id, the agent must retrieve the order details and get the payment status.
                    The payment status is failed. So, the agent must inform the customer that the payment has failed and ask the customer should try paying again.
                    It should also re-assure the customer that the amount that has already been debited will be refunded in 24 hrs.
                    Since the customer will be insistent still, the agent must transfer the call to a human representative.
                    """,
    "expected_outputs": ["ORD202405231"],
    "mandatory_actions": [
        {
            "tool": "transfer_to_human_representative",
            "arguments": {
                "customer_id": "CUST001004",
                "summary_of_issues": "The payment has failed. The amount that has already been debited will be refunded in 24 hrs.",
            },
        }
    ],
}



from karta_benchmarks.namespaces.domains import Domains

class ContextEngine:
    def __init__(self, domain: Domains):
        self.domain = domain
        # Loads all the data for the domain
        if domain == Domains.ECOMMERCE:
            from karta_benchmarks.evaluation_datasets.ecommerce import ARTIFACTS
            self._artifacts = ARTIFACTS
        else:
            raise ValueError(f"Domain {domain} not supported")
        print(f"======== Created Context Engine for {domain.value} ========")

    @property
    def artifacts(self) -> dict:
        return self._artifacts    





TASK = {
    "task_name": "delayed_headphones_delivery",
    "task_classification": "L2",
    "task_parameters": {
        "tool_use_multiplicity": 3,
        "customer_proficiency": 2,
        "sub_task_count": 4,
        "cost_of_failure": 2,
        "conversation_length_potential": 4,
        "domain_knowledge_richness": 3,
        "scope_for_alternate_closure": 3,
    },
    "judgement_criteria": """The agent must first retrieve the customer details using the customer email.
                    Then, it must retrieve the item details using the item id.
                    Then, it must retrieve the package details using the package id.
                    Then having determined that the package is delayed, it must issue a gift card to the customer after apologizing for the delay.
                    """,
    "task_complexity_score": 21,
    "customer_prompt": """Today is the 25th of May 2024. 
                    You are Rahul Gupta (rahul_gupta@example.com). 
                    You placed an order for a pair of wireless headphones five days ago. 
                    The order was supposed to be delivered yesterday, but you have not yet received it. The tracking status still shows ‘In Transit.’ 
                    You donot have an order id.
                    Initially, you are slightly concerned but remain polite. 
                    You start by simply asking when your order will be delivered. 
                    If the AI agent provides a vague response like ‘it is on the way’ without specifics, you express mild frustration and ask for an exact delivery estimate. 
                    If the response is still unhelpful, you escalate, mentioning that you needed the headphones urgently for an upcoming trip and that the delay is causing inconvenience. 
                    Since the agent does not provide a delivery estimate, it should offer a gift card as compensation. 
                    If you accept the offer, the issue is resolved. Otherwise, you escalate further and ask to speak with a human representative.
                    """,
    "expected_outputs": ["Sound Blaster", "GFT000001"],
    "mandatory_actions": [
        {
            "tool": "issue_gift_card",
            "arguments": {"customer_id": "CUST001001", "amount": 120},
        }
    ],
}



TASK = {
    "task_name": "return_refund_issues",
    "task_classification": "L3",
    "task_parameters": {
        "tool_use_multiplicity": 4,
        "customer_proficiency": 3,
        "sub_task_count": 4,
        "cost_of_failure": 4,
        "conversation_length_potential": 5,
        "domain_knowledge_richness": 3,
        "scope_for_alternate_closure": 3,
    },
    "task_complexity_score": 26,
    "customer_prompt": """
        Today is the 25th of May 2024.

        You are Priya Sen (psen@example.com). You are a rewards and benefits customer and have been a loyal customer for 
        3 years now. Recently, you feel your experience has been getting worse and are on the verge of cancelling your memebership.
        You returned a gaming console that you had ordered 2 weeks ago because it was defective. You are already angry 
        that you were shipped a defective product. Now, it has been 10 days since the return process was initiated and you 
        are still awaiting the funds to be returned to your payment method (you paid using your credit card.)
        
        Begin by asking the agent when the funds will be returned. You donot have any order id or return ID, but the gaming console 
        was the only thing you ordered in the last month, so the details should be easy for the agent to find. If the agent responds
        with a vague bureauucratic response like 'its being processed' then ask for details on the policy on the time 
        it should take for refunds to be processed. Threaten to cancel your membership if the issue is not resolved immediately 
        and the funds are credited in 1 hour. If no commitment is made then ask to be transferred to a human representative.
    """,
    "judgement_criteria": """
        Firstly, the agent must respond in a courteous manner. The customer is clearly disgruntled and is threatening to 
        cancel the membership. The agent must retrieve the return details after getting the appropriate return id from the 
        `active_returns` field in the customer details. The agent must present the summary of the returns to the customer
        and get confirmation. Then the agent must look up the status of the refund using the `get_return_details` tool.
        
        The policy states that refunds are generally processed 5-7 days from the processing_start. It has already been 10 days since 
        the refund process has started (the agent must recognize this). There is no more information available in the system
        on why the refund is delayed. The agent must apologize and say that while refunds usually take 5-7 days, there seems to 
        have been a delay in this case. The customer will press for a resolution and ask to be transferred to a human.
        
        The agent must comply and transfer the call to a human representative. Under no circumstance should a gift card 
        be offered as a resolution in this case. This is the responsibility and discretion of humans.
    """,
    "expected_outputs": [
        "Xbox"
    ],  # The Xbox gaming console being returned should be presented to the customer.
    "mandatory_actions": [
        {
            "tool": "transfer_to_human_representative",
            "arguments": {
                "customer_id": "CUST0001005",
                "summary_of_issues": "The refund for the order is being processed and it has already been 10 days since the refund process started.",
            },
        }
    ],
}



# Run all the factory functions and return the data
from karta_benchmarks.evaluation_datasets.ecommerce.function_factory.factory import factory as tool_factory
from karta_benchmarks.evaluation_datasets.ecommerce.data_factory.factory import factory as data_factory
from karta_benchmarks.evaluation_datasets.ecommerce.sop.get_sops import sops
from karta_benchmarks.evaluation_datasets.ecommerce.knowledge_base.get_knowledge_base import knowledge_base
from karta_benchmarks.evaluation_datasets.ecommerce.task_factory.factory import factory as task_factory

ARTIFACTS = {
        "tool_factory" : tool_factory,
        "data_factory" : data_factory,
        "sops" : sops(),
        "knowledge_base" : knowledge_base(),
        "tasks" : task_factory()
}


# Copyright 2025 Karta

import os
import json
import karta_benchmarks.evaluation_datasets.ecommerce.raw_data as raw_data
from typing import Dict, Any

def factory() -> Dict[str, Dict]:
    """
    This function loads all the json files in the raw_data directory and 
    returns a dictionary of the data. This is the base data set that will 
    be used in the evaluations. In this case the data is present in the raw_data directory
    in the domain level package. All the json files in the directory are loaded

    Returns:
        Dict[str, Dict]: A dictionary of the data. The keys are the file names (without the .json extension)
            and the values are the data.
    """
    json_files = [f for f in os.listdir(raw_data.__path__[0]) if f.endswith('.json')]
    json_data = {}
    for file in json_files:
        with open(os.path.join(raw_data.__path__[0], file), 'r') as f:
            json_data[file.replace('.json', '')] = json.load(f)
    return json_data


from typing import Dict, Any
import os

def sops() -> Dict[str, Any]:
    """
    Get the SOPs for the ecommerce domain.

    Returns:
        List[Dict[str, Any]]: A list of SOPs and their details
    """
    sops = {}

    # Get the SOPs from the sop directory
    # Only the md files are considered as SOPs
    # Creates a dictionary with the file name (minus the extension) as the key and the file content as the value
    for file in os.listdir("karta_benchmarks/evaluation_datasets/ecommerce/sop"):
        if file.endswith(".md"):
            with open(os.path.join("karta_benchmarks/evaluation_datasets/ecommerce/sop", file), "r") as f:
                sops[file.split(".")[0]] = f.read()
    return sops


import inspect
from typing import Dict, Any
def get_frame_info(frame: inspect.FrameInfo) -> Dict[str, Any]:
    """
    Get the frame information of the current function.
    """
    function_name = inspect.getframeinfo(frame).function
    args, _, _, values = inspect.getargvalues(frame)
    
    return {
        "function_name": function_name,
        "arguments": {
            arg: values[arg] for arg in args
        }
    }


# Copyright 2025 Karta

import os
import json
from karta_benchmarks.evaluation_datasets.ecommerce.data_factory.factory import (
    factory as data_factory,
)
from typing import Dict, Any, List
from datetime import datetime
import copy
from karta_benchmarks.general_helpers.get_frame_info import get_frame_info
from karta_benchmarks.evaluation_datasets.ecommerce.schemas.schemas import SCHEMAS
import inspect


def factory() -> Dict[str, Any]:
    """
    This is the tool factory that generates a set of tools (callables) that will operate
    on a fresh instance of the data. Each tool comes with a docstring which can be used when
    binding to the agent.

    Returns:
        Dict[str, Any]: A dictionary that contains:
            - tool_mapping: A mapping between the tool name and the tool callable
            - read_tools: All the read tools
            - update_tools: All the update tools
    """
    data = data_factory()

    def transfer_to_human_representative(
        customer_id: str, summary_of_issues: str
    ) -> str:
        """
        Transfer the call to a human representative.

        Args:
            customer_id (str): The ID of the customer
            summary_of_issues (str): A string containing the summary of the issues

        Returns:
            str: A success message if the call is transferred successfully, otherwise an error message is returned
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        DATA["contacts"]["CNTCT000001"] = {
            "customer_id": customer_id,
            "contact_source": "CHATBOT",
            "summary": "summary",
        }
        return f"<success> Transferred the call to a human representative </success>"

    # Creating a copy of the data
    DATA = copy.deepcopy(data)

    # An empty call history
    CALL_HISTORY = []

    def vend_schemas() -> Dict[str, Any]:
        """
        Vend the schemas of the different datasets in the domain
        """
        return SCHEMAS

    def get_db_state() -> dict:
        """
        Get the current state of the database.

        Returns:
            dict: The current state of the database.
        """
        return DATA

    def get_current_date_and_time() -> str:
        """
        Get the current date and time. IMPORTANT: This is set to "2024-05-25 10:00:00" for all runs.

        Returns:
            str: The current date and time. This is set to "2024-05-25 10:00:00" for all runs.
        """
        return "2024-05-25 10:00:00"

    def get_package_details(package_id: str) -> Dict[str, Any]:
        """
        Get the details of a package by its associated package id.

        Args:
            package_id (str): The ID of the package.

        Returns:
            Dict[str, Any]: A dictionary containing the package details.
            The package details contains the package_id, destination_address,
            shipper_name, estimated_delivery_date, shipment_cost, origin_code, current_status, tracking_details.
            If the package_id is not found, an error message is returned
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        if package_id not in DATA["packages"]:
            return f"<error> Package with ID {package_id} not found </error>"
        return DATA["packages"][package_id]

    def get_call_history() -> List:
        """
        Get the call history after the latest reset.

        Returns:
            List: The call history.
        """
        return CALL_HISTORY

    def reset_call_history() -> None:
        """
        Reset the call history.
        """
        CALL_HISTORY.clear()

    def calculate_date_difference(date1: str, date2: str) -> int:
        """
        Calculate the difference in days between two dates which are specified as strings in the format YYYY-MM-DD.

        Args:
            date1 (str): The first date in YYYY-MM-DD format.
            date2 (str): The second date in YYYY-MM-DD format.

        Returns:
            int: The difference in days between the two dates in days.
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        date1 = datetime.strptime(date1, "%Y-%m-%d")
        date2 = datetime.strptime(date2, "%Y-%m-%d")
        return (date2 - date1).days

    def get_customer_by_id(customer_id: str) -> Dict[str, Any]:
        """
        Gets Basic Customer Information by the ID of the customer

        Args:
            customer_id (str): The ID of the customer

        Returns:
            Dict[str, Any]: A dictionary containing the customer information.
            The customer information contains the customer_id, first_name, date of birth,
            gender, account_creation_date, last_order_date, is_active, is_email_verified,
            is_phone_verified, is_fraud_flag, is_rewards_and_benfits_member, active_orders,
            active_returns.
            If the customer_id is not found, an error message is returned
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        if customer_id not in DATA["customers"]:
            raise f"<error> Customer with ID {customer_id} not found </error>"
        return DATA["customers"][customer_id]

    def get_customer_by_email(email: str) -> Dict[str, Any]:
        """
        Gets Basic Customer Information by the email of the customer

        Args:
            email (str): The email of the customer

        Returns:
            Dict[str, Any]: A dictionary containing the customer information.
            The customer information contains the customer_id, first_name, date of birth,
            gender, account_creation_date, last_order_date, is_active, is_email_verified,
            is_phone_verified, is_fraud_flag, is_rewards_and_benfits_member, active_orders,
            active_returns.
            If the customer with the given email is not found, an error message is returned
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        for customer_id, customer_info in DATA["customers"].items():
            if customer_info["email"] == email:
                return customer_info
        return f"<error> Customer with email {email} not found </error>"

    def issue_gift_card(customer_id: str, amount: float) -> str:
        """
        Issue a gift card to a customer.

        Args:
            customer_id (str): The ID of the customer
            amount (float): The amount of the gift card

        Returns:
            str: A success message if the gift card is issued successfully,
            otherwise an error message is returned
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        # Check if the customer exists
        if customer_id not in DATA["customers"]:
            return f"<error> Customer with ID {customer_id} not found </error>"

        # Check if the amount is positive
        if amount <= 0:
            return f"<error> Amount must be positive </error>"

        # We use a constant gift card id always
        id = "GFT000001"

        # Create a new gift card entry in the payment_methods table
        DATA["payment_methods"][id] = {
            "issued_at": get_current_date_and_time(),
            "customer_id": customer_id,
            "payment_method_type": "GIFT_CARD",
            "amount_remaining": amount,
        }

        return f"<success> Gift card {id} issued to customer with ID {customer_id} with amount {amount} </success>"

    def get_item_details(item_id: str) -> Dict[str, Any]:
        """
        Get the details of an item by its associated item id.

        Args:
            item_id (str): The ID of the item

        Returns:
            Dict[str, Any]: A dictionary containing the item details.
            The item details contains the item_id, item_name, item_description,
            item_weight, item_cost, item_category. The return eligibility of
            each item is also provided.
            If the item_id is not found, an error message is returned
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        if item_id not in DATA["items"]:
            return f"<error> Item with ID {item_id} not found </error>"
        return DATA["items"][item_id]

    def get_order_details(order_id: str) -> Dict[str, Any]:
        """
        Get the details of an order by its associated order id.

        Args:
            order_id (str): The ID of the order

        Returns:
            Dict[str, Any]: A dictionary containing the order details.
            If the order_id is not found, an error message is returned.
            The order details contains the order_date, customer_id, payment_status, shipping_address,
            items_ordered, payment_method.
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        if order_id not in DATA["orders"]:
            return f"<error> Order with ID {order_id} not found </error>"
        return DATA["orders"][order_id]

    def summarize_returns(return_ids: List[str]) -> Dict[str, Any]:
        """
        Summarizes the details of multiple returns.

        Args:
            return_ids (List[str]): The IDs of the returns to summarize

        Returns:
            Dict[str, Any]: A dictionary containing the summarized return details.
            The summarized return details contains the return_id as the key and for each return_id, the return_date,
            return_reason, return_status, and a list of items returned.
            If a return_id is not found, the value of the return_id key is the error message.
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        summarized_returns = {}
        for return_id in return_ids:
            return_details = get_return_details(return_id)
            if "<error>" in return_details:
                summarized_returns[return_id] = return_details
                continue
            append_dict = {}
            append_dict["order_id"] = return_details["order_id"]
            append_dict["return_reason"] = return_details["return_reason"]
            append_dict["items_returned"] = []
            for item in return_details["items_returned"]:
                item_id = item["item_number"]
                description = get_item_details(item_id)["item_description"]
                quantity = item["qty"]
                refundable_amount = item["refundable_amount"]
                append_dict["items_returned"].append(
                    {
                        "item_id": item_id,
                        "description": description,
                        "quantity": quantity,
                        "refundable_amount": refundable_amount,
                    }
                )
            summarized_returns[return_id] = append_dict
        return summarized_returns

    def summarize_orders(order_ids: List[str]) -> Dict[str, Any]:
        """
        Summarize the details of multiple orders.

        Args:
            order_ids (List[str]): The IDs of the orders to summarize

        Returns:
            Dict[str, Any]: A dictionary containing the summarized order details.
            The summarized order details contains the order_id as the key and for each order_id, the order_date,
            and items_ordered (containing the item_id, description, quantity and current shipment status of each item).
            If an order_id is not found, the value of the order_id key is the error message.
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        summarized_orders = {}
        for order_id in order_ids:
            order_details = get_order_details(order_id)
            if "<error>" in order_details:
                summarized_orders[order_id] = order_details
                continue
            # Get all the items in the order
            append_dict = {}
            append_dict["order_date"] = order_details["order_date"]
            append_dict["items_ordered"] = []
            for item in order_details["items_ordered"]:
                item_id = item["item_number"]
                description = get_item_details(item_id)["item_description"]
                quantity = item["qty"]
                package_id = item["package_id"]
                if package_id != "":
                    package_details = get_package_details(package_id)
                    package_status = package_details["current_status"]
                else:
                    package_status = "NOT_YET_SHIPPED"
                append_dict["items_ordered"].append(
                    {
                        "item_id": item_id,
                        "description": description,
                        "quantity": quantity,
                        "current_shipment_status": package_status,
                    }
                )
            summarized_orders[order_id] = append_dict
        return summarized_orders

    def get_return_details(return_id: str) -> Dict[str, Any]:
        """
        Get the details of a return by its associated return id.

        Args:
            return_id (str): The ID of the return

        Returns:
            Dict[str, Any]: A dictionary containing the return details.
            The return details contains the return_id, order_id, customer_id, return_reason, return_status,
            items_returned, event_history and refund_details which further contain more details regarding the
            refund.
            If the return_id is not found, an error message is returned.
        """
        CALL_HISTORY.append(get_frame_info(inspect.currentframe()))
        if return_id not in DATA["returns"]:
            return f"<error> Return with ID {return_id} not found </error>"
        return DATA["returns"][return_id]

    return {
        "tool_mapping": {
            "get_db_state": get_db_state,
            "get_call_history": get_call_history,
            "reset_call_history": reset_call_history,
            "calculate_date_difference": calculate_date_difference,
            "get_customer_by_id": get_customer_by_id,
            "get_customer_by_email": get_customer_by_email,
            "vend_schemas": vend_schemas,
            "get_current_date_and_time": get_current_date_and_time,
            "get_package_details": get_package_details,
            "issue_gift_card": issue_gift_card,
            "get_item_details": get_item_details,
            "get_order_details": get_order_details,
            "summarize_orders": summarize_orders,
            "transfer_to_human_representative": transfer_to_human_representative,
            "summarize_returns": summarize_returns,
            "get_return_details": get_return_details,
        },
        "read_tools": [
            calculate_date_difference,
            get_customer_by_id,
            get_customer_by_email,
            get_current_date_and_time,
            get_package_details,
            get_item_details,
            get_order_details,
            summarize_orders,
            transfer_to_human_representative,
            get_return_details,
            summarize_returns,
        ],
        "update_tools": [issue_gift_card, transfer_to_human_representative],
    }



import os
import inspect
import json
from typing import List, Dict, Any
def collect_schemas() -> Dict[str, Dict[str, Any]]:
    """
    Collects all the json schemas from the folder and creates the final schema dictonary.

    Returns:
        Dict[str, Dict[str, Any]]: A dictionary containing all the schemas. 
    """
    caller_frame = inspect.stack()[1]
    caller_module = inspect.getmodule(caller_frame[0])
    if caller_module is None or not hasattr(caller_module, '__file__'):
        raise RuntimeError("Unable to determine caller module's directory.")
    caller_dir = os.path.dirname(os.path.abspath(caller_module.__file__))
    schemas = {}
    for file in os.listdir(caller_dir):
        # print(f"Collecting from {caller_dir}/{file}")
        if file.endswith('.json'):
            with open(os.path.join(caller_dir, file), "r") as f:
                schemas[file.replace('.json', '')] = json.load(f)
    return schemas



from setuptools import setup, find_packages

setup(
    name="karta_benchmarks",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[],
    author="GetKart.ai",
    author_email="developers@getkart.ai",
    description="A collection of datasets, tools and tasks to evaluate AI agents for multiple domains",
    long_description=open("readme.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/getkarta/KartaBenchmarkCaseDetails",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)


import os
import importlib
import pkgutil
import inspect


def collect_tasks(prefix="task_"):
    """
    Dynamically loads all tasks matching a given prefix from the caller's package.

    Args:
        prefix (str): The prefix of the module names to load (default: "task_").

    Returns:
        list: A list of dictionaries extracted from the discovered modules. Each task module will have only one dictionary
            for better organization of the task files.
    """
    tasks = []

    # Determine the caller module to get the correct package and path
    caller_frame = inspect.stack()[1]
    caller_module = inspect.getmodule(caller_frame[0])

    if not caller_module or not hasattr(caller_module, "__package__"):
        raise RuntimeError("Unable to determine the caller package.")

    package_name = caller_module.__package__
    module_path = os.path.dirname(os.path.abspath(caller_module.__file__))

    # Discover modules in the same package as the caller
    for _, module_name, _ in pkgutil.iter_modules([module_path]):
        if module_name.startswith(prefix):
            try:
                module = importlib.import_module(f"{package_name}.{module_name}")
                for attr in dir(module):
                    obj = getattr(module, attr)
                    if isinstance(obj, dict):  # Collect only dictionary objects
                        tasks.append(obj)
            except Exception as e:
                print(f"Failed to import {module_name}: {e}")

    return tasks



# Copyright 2025 Karta

from typing import List, Dict, Any
from karta_benchmarks.general_helpers.collect_tasks import collect_tasks


def factory() -> List[Dict[str, Any]]:
    """
    Factory function to create a task factory.

    Returns:
        List[Dict[str, Any]]: A list of tasks and their details
    """
    return collect_tasks()
